##  Prerequisites
Before you start, do the following:
  * Install the latest LTS version of [Python![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.python.org%2Fdownloads%2F "https://www.python.org/downloads/").
  * Install [Poetry![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fpython-poetry.org%2Fdocs%2F "https://python-poetry.org/docs/"), a tool for dependency management and packaging in Python.
  * Install the necessary dependencies. In this tutorial, we use the [requests![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Frequests.readthedocs.io%2Fen%2Flatest%2F "https://requests.readthedocs.io/en/latest/") Python library. You can install it by executing the following command:

```
poetry add requests
```



  * Learn how to authenticate to SAP LeanIX APIs. Fore more information, see [Authentication to SAP LeanIX Services](https://help.sap.com/docs/leanix/ea/authentication-to-sap-leanix-services?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to authenticate to SAP LeanIX services.").


This tutorial assumes you have basic knowledge of:
  * Python and Python virtual environments
  * GraphQL
